.. image:: http://docs.wand-py.org/en/latest/_static/wand.png
   :width: 120
   :height: 120

Wand_
=====

Wand is a ``ctypes``-based simple ImageMagick_ binding for Python.
It doesn't cover all functionalities of MagickWand API currently.
It works on Python 2.6, 2.7, 3.2, 3.3, and PyPy.

You can install the package from PyPI_ by using ``pip`` or
``easy_install``:

.. code-block:: console

   $ pip install Wand

Or would you like to enjoy with bleeding edge?  Check out the head
revision of the source code from the `GitHub repository`__:

.. code-block:: console

   $ git clone git://github.com/dahlia/wand.git
   $ cd wand/
   $ python setup.py install

.. _Wand: http://wand-py.org/
.. _ImageMagick: http://www.imagemagick.org/
.. _PyPI: https://pypi.python.org/pypi/Wand
__ https://github.com/dahlia/wand


Docs
----

Recent version
   http://docs.wand-py.org/

Development version
   http://docs.wand-py.org/en/latest/


Community
---------

Website
   http://wand-py.org/

GitHub
   https://github.com/dahlia/wand

Package Index (Cheeseshop)
   https://pypi.python.org/pypi/Wand

Mailing list
   wand@librelist.com

List archive
   http://librelist.com/browser/wand/

Quora topic (Q&A)
   https://www.quora.com/Wand-ImageMagick-binding

IRC
   `irc://irc.freenode.net/wand <http://webchat.freenode.net/?channels=wand>`_

Continuous Integration (Travis CI)
   http://travis-ci.org/dahlia/wand

   .. image:: https://secure.travis-ci.org/dahlia/wand.png?branch=master
      :alt: Build Status
      :target: http://travis-ci.org/dahlia/wand

Code Coverage
   https://coveralls.io/r/dahlia/wand

   .. image:: https://coveralls.io/repos/dahlia/wand/badge.png
      :alt: Coverage Status
      :target: https://coveralls.io/r/dahlia/wand
